@@ -24,7 +24,7 @@ class Clipboard(object):
                                 stdout=subprocess.PIPE)
         return proc.stdout.read()
 
-    def _read_posix(self):
+    def _read_linux2(self):
         if os.environ.get('DISPLAY') is not None:
             xsel = find_executable('xsel')
             if xsel is not None:
@@ -34,7 +34,11 @@ class Clipboard(object):
                 return os.popen('%s -o' % xclip).read()
 
     def read(self):
-        return getattr(self, '_read_%s' % sys.platform)()
+        meth = '_read_%s' % sys.platform
+        if hasattr(self, meth):
+            return getattr(self, meth)()
+        else:
+            return self._read_linux2()
 
     def _write_process(self, cmd, value):
         proc = subprocess.Popen(cmd, shell=True, stdin=subprocess.PIPE)
@@ -57,7 +61,7 @@ class Clipboard(object):
     def _write_darwin(self, value):
         self._write_process('/usr/bin/pbcopy', value)
 
-    def _write_posix(self, value):
+    def _write_linux2(self, value):
         if os.environ.get('DISPLAY') is not None:
             xsel = find_executable('xsel')
             if xsel is not None:
@@ -67,7 +71,12 @@ class Clipboard(object):
                 self._write_process('%s -i' % xclip, value)
 
     def write(self, value):
-        getattr(self, '_write_%s' % sys.platform)(value)
+        meth = '_write_%s' % sys.platform
+        if hasattr(self, meth):
+            getattr(self, meth)(value)
+        else:
+            # default
+            self._write_linux2(value)
 
 
 def main(service):
